@@ -15,7 +15,7 @@ APPLE_MFR_ID = 76
 IBEACON_FIRST_BYTE = 0x02
 IBEACON_SECOND_BYTE = 0x15
 
-__version__ = "0.7.2"
+__version__ = "0.7.3"
 
 __all__ = [
     "parse",
@@ -108,7 +108,7 @@ def parse(service_info: BluetoothServiceInfo) -> iBeaconAdvertisement | None:
 
 def calculate_distance_meters(power: int, rssi: int) -> float | None:
     """Calculate the distance in meters between the device and the beacon."""
-    if rssi == 0:
+    if rssi == 0 or power == 0:
         return None
     if (ratio := rssi * 1.0 / power) < 1.0:
         distance = pow(ratio, 10)
